Releases
++++++++

How to cite
===========

In the academic spirit of collaboration, the source code should be appropriately acknowledged in the resulting scientific disseminations.
You may cite it as follows:

* [1], for general reference to the EnergyScope project and the EnergyScope modeling framework
* [2], for reference to the origins of the EnergyScope project or to the first online version of the calculator energyscope.ch
* [3], for reference to the energyscope MILP modeling framework
* [4], for reference to the current code

You are welcome to report any bugs related to the code to the following:
moret.stefano@gmail.com or gauthierLimpens@gmail.com

License
=======

Copyright (C) <2018-2021> <Ecole Polytechnique Fédérale de Lausanne (EPFL), Switzerland and Université catholique de Louvain (UCLouvain), Belgium>

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License

Codes versions
==============
- first release (v1, monthly MILP) of the EnergyScope (ES) model: https://github.com/energyscope/EnergyScope/tree/v1.0 . See [2]
- second release (v2, hourly LP) of the EnergyScope (ES) model: https://github.com/energyscope/EnergyScope/tree/v2.0 .	See [1]
- second release with energy system improvment (v2.1 Energy system update) of EnergyScope (ES) model: https://github.com/energyscope/EnergyScope/tree/v2.1 . See [3]

Authors: 
- Stefano Moret, Ecole Polytechnique Fédérale de Lausanne (Switzerland), <moret.stefano@gmail.com> 
- Gauthier Limpens, Université catholique de Louvain (Belgium), <gauthierLimpens@gmail.com>  
- Paolo Thiran, Université catholique de Louvain (Belgium)
- Xavier Rixhon, Université catholique de Louvain (Belgium)

Applications
============

Other countries:
----------------

The model has been applied to the following countries:

- Switzerland:
  
    * [X] Uncertainty
    * [X] Storage needs
  
- Belgium:
  
    * [X] Scenarios for the transition
  
- Italy:
  
    * [X] Scenarios for the transition
  
- Spain:
  
    * [X] Scenarios for the transition
  
- Other countries:
  
    * [X] EU countries
    * [X] Multi-cells
  
Current developments:
=====================
Pathway, multi-cells, (myopic) (something more from EPFL?)

Bibliography
============

[1] G. Limpens, S . Moret, H. Jeanmart, F. Maréchal (2019). EnergyScope TD: a novel open-source model for regional energy systems and its application to the case of Switzerland. https://doi.org/10.1016/j.apenergy.2019.113729	

[2] V. Codina Gironès, S. Moret, F. Maréchal, D. Favrat (2015). Strategic energy planning for large-scale energy systems: A modelling framework to aid decision-making. Energy, 90(PA1), 173–186. https://doi.org/10.1016/j.energy.2015.06.008   	

[3] S. Moret, M. Bierlaire, F. Maréchal (2016). Strategic Energy Planning under Uncertainty: a Mixed-Integer Linear Programming Modeling Framework for Large-Scale Energy Systems. https://doi.org/10.1016/B978-0-444-63428-3.50321-0  	


